<?php
/**
 * @package		Testimonial
 * @copyright	Copyright (C) 2015 Fido-X IT (John Simon). All rights reserved. (fido-x.net)
 * @license		GNU General Public License version 3; see http://www.gnu.org/licenses/gpl-3.0.en.html
 */

class ModelFidoTestimonial extends Model {
	public function createTestimonials() {
		$create_testimonial = "CREATE TABLE IF NOT EXISTS `" . DB_PREFIX . "testimonial` (`testimonial_id` int(11) NOT NULL auto_increment, `customer_id` int(11) NOT NULL default 0, `status` int(1) NOT NULL default '0', `firstname` varchar(32) NOT NULL default '', `lastname` varchar(32) NOT NULL default '', `email` varchar(96) NOT NULL default '', `website` varchar(128) NOT NULL default '', `company` varchar(128), `title` varchar(128), `rating` int(1) NOT NULL default '0', `language_code` varchar(5) NOT NULL default 'en', `testimony` text NOT NULL, `image` varchar(255), `featured` int(1) NOT NULL default 0, `date_added` datetime NOT NULL, `date_modified` datetime NOT NULL, PRIMARY KEY (`testimonial_id`)) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;";
		$this->db->query($create_testimonial);

		$create_testimonial_to_store = "CREATE TABLE IF NOT EXISTS `" . DB_PREFIX . "testimonial_to_store` (`testimonial_id` int(11) NOT NULL, `store_id` int(11) NOT NULL, PRIMARY KEY (`testimonial_id`,`store_id`)) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;";
		$this->db->query($create_testimonial_to_store);
	}

	public function dropTestimonials() {
		$drop_testimonial = "DROP TABLE IF EXISTS `" . DB_PREFIX . "testimonial`;";
		$this->db->query($drop_testimonial);

		$drop_testimonial_to_store = "DROP TABLE IF EXISTS `" . DB_PREFIX . "testimonial_to_store`;";
		$this->db->query($drop_testimonial_to_store);
	}

	public function addTestimonial($data) {
		$this->db->query("INSERT INTO " . DB_PREFIX . "testimonial SET firstname = '" . $this->db->escape($data['firstname']) . "', lastname = '" . $this->db->escape($data['lastname']) . "', email = '" . $this->db->escape($data['email']) . "', website = '" . $this->db->escape($data['website']) . "', rating = '" . (int)$data['rating'] . "', company = '" . $this->db->escape($data['company']) . "', title = '" . $this->db->escape($data['title']) . "', language_code = '" . $data['language_code'] . "', testimony = '" . $this->db->escape($data['testimony']) . "', featured = '" . (int)$data['featured'] . "', status = '" . (int)$data['status'] . "', date_added = NOW(), date_modified = NOW()");

		$testimonial_id = $this->db->getLastId();

		if (isset($data['image'])) {
			$this->db->query("UPDATE " . DB_PREFIX . "testimonial SET image = '" . $this->db->escape($data['image']) . "' WHERE testimonial_id = '" . (int)$testimonial_id . "'");
		}

		if (isset($data['testimonial_store'])) {
			foreach ($data['testimonial_store'] as $store_id) {
				$this->db->query("INSERT INTO " . DB_PREFIX . "testimonial_to_store SET testimonial_id = '" . (int)$testimonial_id . "', store_id = '" . (int)$store_id . "'");
			}
		}

		$this->cache->delete('testimonial');
	}

	public function editTestimonial($testimonial_id, $data) {
		$this->db->query("UPDATE " . DB_PREFIX . "testimonial SET firstname = '" . $this->db->escape($data['firstname']) . "', lastname = '" . $this->db->escape($data['lastname']) . "', email = '" . $this->db->escape($data['email']) . "', website = '" . $this->db->escape($data['website']) . "', company = '" . $this->db->escape($data['company']) . "', title = '" . $this->db->escape($data['title']) . "', rating = '" . (int)$data['rating'] . "', language_code = '" . $data['language_code'] . "', testimony = '" . $this->db->escape($data['testimony']) . "', featured = '" . (int)$data['featured'] . "', status = '" . (int)$data['status'] . "', date_modified = NOW() WHERE testimonial_id = '" . (int)$testimonial_id . "'");

		if (isset($data['image'])) {
			$this->db->query("UPDATE " . DB_PREFIX . "testimonial SET image = '" . $this->db->escape($data['image']) . "' WHERE testimonial_id = '" . (int)$testimonial_id . "'");
		}

		$this->db->query("DELETE FROM " . DB_PREFIX . "testimonial_to_store WHERE testimonial_id = '" . (int)$testimonial_id . "'");

		if (isset($data['testimonial_store'])) {
			foreach ($data['testimonial_store'] as $store_id) {
				$this->db->query("INSERT INTO " . DB_PREFIX . "testimonial_to_store SET testimonial_id = '" . (int)$testimonial_id . "', store_id = '" . (int)$store_id . "'");
			}
		}

		$this->cache->delete('testimonial');
	}

	public function deleteTestimonial($testimonial_id) {
		$this->db->query("DELETE FROM " . DB_PREFIX . "testimonial WHERE testimonial_id = '" . (int)$testimonial_id . "'");
		$this->db->query("DELETE FROM " . DB_PREFIX . "testimonial_to_store WHERE testimonial_id = '" . (int)$testimonial_id . "'");

		$this->cache->delete('testimonial');
	}

	public function enableTestimonial($testimonial_id) {
		$this->db->query("UPDATE " . DB_PREFIX . "testimonial SET status = '1' WHERE testimonial_id = '" . (int)$testimonial_id . "'");
	}

	public function disableTestimonial($testimonial_id) {
		$this->db->query("UPDATE " . DB_PREFIX . "testimonial SET status = '0' WHERE testimonial_id = '" . (int)$testimonial_id . "'");
	}

	public function featureTestimonial($testimonial_id) {
		$this->db->query("UPDATE " . DB_PREFIX . "testimonial SET featured = '1' WHERE testimonial_id = '" . (int)$testimonial_id . "'");
	}

	public function unfeatureTestimonial($testimonial_id) {
		$this->db->query("UPDATE " . DB_PREFIX . "testimonial SET featured = '0' WHERE testimonial_id = '" . (int)$testimonial_id . "'");
	}

	public function getTestimonial($testimonial_id) {
		$query = $this->db->query("SELECT DISTINCT * FROM " . DB_PREFIX . "testimonial WHERE testimonial_id = '" . (int)$testimonial_id . "'");

		return $query->row;
	}

	public function getTestimonials($data = array()) {
		if ($data) {
			$sql = "SELECT * FROM " . DB_PREFIX . "testimonial";

			$sort_data = array(
				'lastname',
				'email',
				'status',
				'featured',
				'rating',
				'date_added'
			);

			if (isset($data['sort']) && in_array($data['sort'], $sort_data)) {
				$sql .= " ORDER BY " . $data['sort'];
			} else {
				$sql .= " ORDER BY date_added";
			}

			if (isset($data['order']) && ($data['order'] == 'DESC')) {
				$sql .= " DESC";
			} else {
				$sql .= " ASC";
			}

			if (isset($data['start']) || isset($data['limit'])) {
				if ($data['start'] < 0) {
					$data['start'] = 0;
				}

				if ($data['limit'] < 1) {
					$data['limit'] = 20;
				}

				$sql .= " LIMIT " . (int)$data['start'] . "," . (int)$data['limit'];
			}

			$query = $this->db->query($sql);

			return $query->rows;
		} else {
			$testimonial_data = $this->cache->get('testimonial.' . $this->config->get('config_language_id'));

			if (!$testimonial_data) {
				$query = $this->db->query("SELECT * FROM " . DB_PREFIX . "testimonial ORDER BY date_added DESC");

				$testimonial_data = $query->rows;

				$this->cache->set('testimonial.' . $this->config->get('config_language_id'), $testimonial_data);
			}

			return $testimonial_data;
		}
	}

	public function getTotalTestimonials() {
      	$query = $this->db->query("SELECT COUNT(*) AS total FROM " . DB_PREFIX . "testimonial");

		return $query->row['total'];
	}

	public function getTestimonialStores($testimonial_id) {
		$testimonial_store_data = array();

		$query = $this->db->query("SELECT * FROM " . DB_PREFIX . "testimonial_to_store WHERE testimonial_id = '" . (int)$testimonial_id . "'");

		foreach ($query->rows as $result) {
			$testimonial_store_data[] = $result['store_id'];
		}

		return $testimonial_store_data;
	}

	public function getTotalTestimonialsAwaitingApproval() {
		$query = $this->db->query("SELECT COUNT(*) AS total FROM " . DB_PREFIX . "testimonial WHERE status = '0'");

		return $query->row['total'];
	}

	public function emailExists($email) {
		$query = $this->db->query("SELECT COUNT(*) AS total FROM  " . DB_PREFIX . "testimonial WHERE LCASE(email) = LCASE('" . $this->db->escape($email) . "')");

		if ($query->row) {
			return $query->row['total'];
		} else {
			return false;
		}
	}
}
