<?php
/**
 * @package		Testimonial
 * @copyright	Copyright (C) 2015 Fido-X IT (John Simon). All rights reserved. (fido-x.net)
 * @license		GNU General Public License version 3; see http://www.gnu.org/licenses/gpl-3.0.en.html
 */

class ControllerInformationTestimonial extends Controller {
	public function index() {
    	$this->load->language('information/testimonial');
		$this->load->model('fido/testimonial');
		$this->load->model('tool/image');

		$this->document->setTitle($this->language->get('heading_title'));

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/home')
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('information/testimonial')
		);

		$data['heading_title'] = $this->language->get('heading_title');
		$data['heading_testify'] = $this->language->get('heading_testify');

		$data['text_testimonials'] = $this->language->get('text_testimonials');
		$data['text_more'] = $this->language->get('text_more');
		$data['text_no_testimonials'] = $this->language->get('text_no_testimonials');
		$data['text_login_required'] = sprintf($this->language->get('text_login_required'), $this->url->link('account/login', '', 'SSL'), $this->url->link('account/register', '', 'SSL'));
		$data['text_date_added'] = $this->language->get('text_date_added');

		$data['entry_firstname'] = $this->language->get('entry_firstname');
		$data['entry_lastname'] = $this->language->get('entry_lastname');
		$data['entry_email'] = $this->language->get('entry_email');
		$data['entry_website'] = $this->language->get('entry_website');
		$data['entry_company'] = $this->language->get('entry_company');
		$data['entry_title'] = $this->language->get('entry_title');
		$data['entry_testimony'] = $this->language->get('entry_testimony');
		$data['entry_rating'] = $this->language->get('entry_rating');
		$data['entry_bad'] = $this->language->get('entry_bad');
		$data['entry_good'] = $this->language->get('entry_good');

		$data['help_website'] = $this->language->get('help_website');

		$data['button_testify'] = $this->language->get('button_testify');
		$data['button_continue'] = $this->language->get('button_continue');
		$data['button_submit'] = $this->language->get('button_submit');

		$data['testify'] = $this->url->link('information/testimonial/testify');
		$data['continue'] = $this->url->link('common/home');

		$data['show_excerpt'] = $this->config->get('module_testimonial_page_excerpt');

		$data['show_photo'] = $this->config->get('module_testimonial_page_photo');

		$data['show_rating'] = $this->config->get('module_testimonial_page_rating');

		$data['login_required'] = $this->config->get('module_testimonial_login_required');

		if ($this->customer->isLogged()) {
			$data['email_exists'] = $this->model_fido_testimonial->emailExists($this->customer->getEmail());

			$data['is_logged'] = true;
		} else {
			if (isset($this->session->data['guest']['email'])) {
				$data['email_exists'] = $this->model_fido_testimonial->emailExists($this->session->data['guest']['email']);
			} else {
				$data['email_exists'] = false;
			}

			$data['is_logged'] = false;
		}

		if (isset($this->request->get['page'])) {
			$page = $this->request->get['page'];
		} else {
			$page = 1;
		}

		if ($this->config->get('module_testimonial_pagination_limit')) {
			$limit = $this->config->get('module_testimonial_pagination_limit');
		} else {
			$limit = $this->config->get($this->config->get('config_theme') . '_product_limit');
		}

		$data['testimonials'] = array();

		$filter_data = array(
			'language'  => $this->session->data['language'],
			'start'     => ($page - 1) * $limit,
			'limit'     => $limit
		);

		$testimonial_total = $this->model_fido_testimonial->getTotalTestimonials($filter_data);

		$results = $this->model_fido_testimonial->getTestimonials($filter_data);

		foreach ($results as $result) {
			if ($result['image'] && file_exists(DIR_IMAGE . $result['image'])) {
				$photo = $this->model_tool_image->resize($result['image'], $this->config->get('module_testimonial_page_photo_width'), $this->config->get('module_testimonial_page_photo_height'));
			} else {
				$photo = $this->model_tool_image->resize('no_photo.jpg', $this->config->get('module_testimonial_page_photo_width'), $this->config->get('module_testimonial_page_photo_height'));
			}

			$data['testimonials'][] = array(
				'testimony'  => utf8_substr(strip_tags(html_entity_decode($result['testimony'], ENT_QUOTES, 'UTF-8')), 0, $this->config->get('module_testimonial_page_numchars')) . '...',
				'name'       => $result['firstname'] . ' ' . $result['lastname'],
				'website'    => $result['website'],
				'company'    => $result['company'],
				'title'      => $result['title'],
				'photo'      => $photo,
			    'rating'     => (int)$result['rating'],
				'date_added' => date($this->language->get('date_format_short'), strtotime($result['date_added'])),
				'href'       => $this->url->link('information/testimonial/info', 'testimonial_id=' . $result['testimonial_id'] . '&page=' . $page)
			);
		}

		$pagination = new Pagination();
		$pagination->total = $testimonial_total;
		$pagination->page = $page;
		$pagination->limit = $limit;
		$pagination->url = $this->url->link('information/testimonial', 'page={page}');

		$data['pagination'] = $pagination->render();

		$data['results'] = sprintf($this->language->get('text_pagination'), ($testimonial_total) ? (($page - 1) * $limit) + 1 : 0, ((($page - 1) * $limit) > ($testimonial_total - $limit)) ? $testimonial_total : ((($page - 1) * $limit) + $limit), $testimonial_total, ceil($testimonial_total / $limit));

		$data['pagination'] = $pagination->render();

		// Captcha
		if ($this->config->get($this->config->get('config_captcha') . '_status') && in_array('testimonial', (array)$this->config->get('config_captcha_page'))) {
			$data['captcha'] = $this->load->controller('captcha/' . $this->config->get('config_captcha'), $this->error);
		} else {
			$data['captcha'] = '';
		}

		$data['breadcrumb'] = $this->load->controller('common/breadcrumb',$data);

		$data['column_left'] = $this->load->controller('common/column_left');
		$data['column_right'] = $this->load->controller('common/column_right');
		$data['content_top'] = $this->load->controller('common/content_top');
		$data['content_bottom'] = $this->load->controller('common/content_bottom');
		$data['footer'] = $this->load->controller('common/footer');
		$data['header'] = $this->load->controller('common/header');

		$this->response->setOutput($this->load->view('information/testimonial_list', $data));
  	}

	public function info() {
		$this->load->language('information/testimonial');
		$this->load->model('fido/testimonial');

		if (isset($this->request->get['testimonial_id'])) {
			$testimonial_id = $this->request->get['testimonial_id'];
		} else {
			$testimonial_id = 0;
		}

		if (isset($this->request->get['page'])) {
			$page = $this->request->get['page'];
		} else {
			$page = 1;
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/home')
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('information/testimonial')
		);

		$data['text_date_added'] = $this->language->get('text_date_added');

		$data['button_list'] = $this->language->get('button_list');

		$data['list'] = $this->url->link('information/testimonial', 'page=' . $page);

		$data['show_photo'] = $this->config->get('module_testimonial_page_photo');

		$data['show_rating'] = $this->config->get('module_testimonial_page_rating');

		$this->load->model('tool/image');

		$testimonial_info = $this->model_fido_testimonial->getTestimonial($testimonial_id);

		if ($testimonial_info) {
			$testimonial_from = sprintf($this->language->get('text_testimonial_from'), $testimonial_info['firstname'] . ' ' . $testimonial_info['lastname']);

			$this->document->setTitle($testimonial_from);

			$data['breadcrumbs'][] = array(
				'text' => $testimonial_from,
				'href' => $this->url->link('information/testimonial/display', 'testimonial_id=' . $testimonial_info['testimonial_id'])
			);

			$data['heading_title'] = $testimonial_from;

			if ($testimonial_info['image'] && file_exists(DIR_IMAGE . $testimonial_info['image'])) {
				$photo = $this->model_tool_image->resize($testimonial_info['image'], $this->config->get('module_testimonial_page_photo_width'), $this->config->get('module_testimonial_page_photo_height'));
			} else {
				$photo = $this->model_tool_image->resize('no_photo.jpg', $this->config->get('module_testimonial_page_photo_width'), $this->config->get('module_testimonial_page_photo_height'));
			}

			$data['testimonial'] = array(
				'name'          => $testimonial_info['firstname'] . ' ' . $testimonial_info['lastname'],
				'website'       => $testimonial_info['website'],
				'company'       => $testimonial_info['company'],
				'title'         => $testimonial_info['title'],
				'photo'         => $photo,
			    'rating'        => (int)$testimonial_info['rating'],
				'date_added'    => date($this->language->get('date_format_short'), strtotime($testimonial_info['date_added'])),
				'testimony'     => strip_tags(html_entity_decode($testimonial_info['testimony'], ENT_QUOTES, 'UTF-8'))
			);

			$data['breadcrumb'] = $this->load->controller('common/breadcrumb',$data);

			$data['column_left'] = $this->load->controller('common/column_left');
			$data['column_right'] = $this->load->controller('common/column_right');
			$data['content_top'] = $this->load->controller('common/content_top');
			$data['content_bottom'] = $this->load->controller('common/content_bottom');
			$data['footer'] = $this->load->controller('common/footer');
			$data['header'] = $this->load->controller('common/header');

			$this->response->setOutput($this->load->view('information/testimonial_info', $data));
    	} else {
	  		$this->document->setTitle($this->language->get('text_error'));

			$this->data['breadcrumbs'][] = array(
				'text' => $this->language->get('text_error'),
				'href' => $this->url->link('information/testimonial', 'testimonial_id=' . $testimonial_id)
			);

      		$data['heading_title'] = $this->language->get('text_error');

      		$data['text_error'] = $this->language->get('text_error');

      		$data['button_continue'] = $this->language->get('button_continue');

      		$data['continue'] = $this->url->link('common/home');

			$this->response->addHeader($this->request->server['SERVER_PROTOCOL'] . ' 404 Not Found');

			$data['column_left'] = $this->load->controller('common/column_left');
			$data['column_right'] = $this->load->controller('common/column_right');
			$data['content_top'] = $this->load->controller('common/content_top');
			$data['content_bottom'] = $this->load->controller('common/content_bottom');
			$data['footer'] = $this->load->controller('common/footer');
			$data['header'] = $this->load->controller('common/header');

			$data['breadcrumb'] = $this->load->controller('common/breadcrumb',$data);

			$this->response->setOutput($this->load->view('error/not_found', $data));
		}
	}

	public function add() {
		$this->load->language('information/testimonial');
		$this->load->model('fido/testimonial');

		$json = array();

		if ($this->request->server['REQUEST_METHOD'] == 'POST') {
			if ((utf8_strlen($this->request->post['firstname']) < 1) || (utf8_strlen($this->request->post['firstname']) > 32)) {
	      		$json['error']['firstname'] = $this->language->get('error_firstname');
	    	}

			if ((utf8_strlen($this->request->post['lastname']) < 1) || (utf8_strlen($this->request->post['lastname']) > 32)) {
	      		$json['error']['lastname'] = $this->language->get('error_lastname');
	    	}

			$pattern = '/^[A-Z0-9._%-]+@[A-Z0-9][A-Z0-9.-]{0,61}[A-Z0-9]\.[A-Z]{2,6}$/i';

			if ((utf8_strlen($this->request->post['email']) > 96) || !preg_match($pattern, $this->request->post['email'])) {
	      		$json['error']['email'] = $this->language->get('error_email');
			}

			if ($this->model_fido_testimonial->emailExists($this->request->post['email'])) {
	      		$json['error']['email'] = $this->language->get('error_email_exists');
			}

			if (utf8_strlen($this->request->post['testimony']) < 3) {
	      		$json['error']['testimony'] = $this->language->get('error_testimony');
	    	}

			if (!isset($this->request->post['rating']) || !$this->request->post['rating']) {
				$json['error']['rating'] = $this->language->get('error_rating');
			}

			// Captcha
			if ($this->config->get($this->config->get('config_captcha') . '_status') && in_array('testimonial', (array)$this->config->get('config_captcha_page'))) {
				$captcha = $this->load->controller('captcha/' . $this->config->get('config_captcha') . '/validate');

				if ($captcha) {
					$json['error']['captcha'] = $captcha;
				}
			}

			if (isset($json['error']) && !isset($json['error']['warning'])) {
				$json['error']['warning'] = $this->language->get('error_warning');
			}

			if (!isset($json['error'])) {
				$this->model_fido_testimonial->addTestimonial($this->request->post);

				$auto_approve = $this->config->get('module_testimonial_auto_approve');

				if ($auto_approve) {
					$json['success'] = $this->language->get('text_success');
				} else {
					$json['success'] = $this->language->get('text_review');
				}
			}
		}

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}
}
