<?php

class OwcBase extends Model {
    
  const VERSION               = 'v2.5.3';  
  const VERSION_DATE          = '02-02-2022';    
  
  const UPDATE_MESSAGE_TIME   = 24; // 24 hours
  
  const AJAX_MAX_LINE_LEN     = 200;  
  const AJAX_CHARS_BEFORE     = 20;  
  const AJAX_MAX_RESULTS      = 50;  
  
  const SHOP_URL              = 'https://shop.openwebcreations.eu';  
  const SUPPORT_URL           = 'https://support.openwebcreations.eu';
  const FEEDBACK_URL          = 'https://feedback.openwebcreations.eu';
 
  var $logger                 = null;
  var $logfile                = 'owc.log';   
  var $performance            = null;	    
  var $logfile_performance    = 'performance.log';	
  var $startTime1_performance = null; 
  var $startTime2_performance = null; 
  var $debug                  = false;	  
  
  public function __construct($arg) {
	  parent::__construct($arg);  	  
  }
    		
	/**
	* get footer info
  *	 
	* @since   1.0
	*/	
	public function getOWCFooter() {
	  $footer = "<a href='". self::SHOP_URL . "' target='blank'>Open Web Creations</a> &copy; 2009-" . date("Y") . " " . $this->language->get('entry_all_rights_reserved');
	  $footer .= " - <a href='". self::SUPPORT_URL . "' target='blank'>". $this->language->get('entry_support') . "</a>";
	  $footer .= " - <a href='". self::FEEDBACK_URL . "' target='blank'>". $this->language->get('entry_feedback') . "</a>";
	  $footer .= "<br />";	  
	  return $footer;
	}				
	
	/**
	* Check for updates.
	*
	* @param   string Extension filename
	* @param   string settings name for check updates 
	* @param   string settings name for last check updates  
	*
	* @return  update message string  	
  *	 
	* @since   2.4.2
	*/	
	public function checkForUpdates($extention_filename, $extention_name, $settings_updates, $settings_check_updates, $settings_last_check_updates) {
	  
	  $updates_str = "";	  	  
	 
	  if ($this->OwcLoader->OwcBase->checkForUpdate($settings_check_updates, $settings_last_check_updates) || isset($this->request->get['owcupdates'])) {	 	    
	    $updates = $this->getUpdates($extention_filename, $extention_name);  	          
      if (!empty($updates)) {                        
        $extentions_text  = array();
        foreach($updates as $key => $update) {          
          $extension          = explode(';', $update);
          $extension_message  = "<extensions> - " . $extension[0] . " <strong>". $extension[1] . "</strong> (<a class='releasenote' href='". $this->url->link($this->getModulePath() . $extension[3] . '/viewChangelog', $this->getUserToken(), $this->getUrlSSL()) . "&changelog=" . $extension[2] . "&title=". $extension[0] . "'>" . $this->language->get('entry_view_changelog'). "</a> or check <a href='". $this->url->link($this->getModulePath() . $extension[3], $this->getUserToken(), $this->getUrlSSL()) . "'>extension settings</a>)</extensions>";
          $extentions_text[]  = $extension_message;
          $updates[$key]      = $update.";".sprintf($this->language->get('help_updates_available'), 1, $extension_message);
        }
        $updates_str = sprintf($this->language->get('help_updates_available'), (count($updates)>1 ? count($updates) : ''), implode('<br />', $extentions_text));
                
        $this->OwcLoader->OwcBase->updateLastCheckForUpdates($updates, $settings_updates, $settings_last_check_updates);        
      } else {
        // No updates available 
        $this->OwcLoader->OwcBase->updateLastCheckForUpdates('', $settings_updates, $settings_last_check_updates);
       
        $this->config->set($settings_updates, '');
      }             
	  }	else
	  if ($this->config->get($settings_check_updates) && $this->config->get($settings_updates)) {
	    $updates = $this->config->get($settings_updates);  	    
	    if (is_array($updates)) {	      
  	    $currentVersion   = (string)$this->config->get($extention_filename . '_version');	   	       
	      $extentions_text  = array();
  	    foreach($updates as $key => $update) {	      
          $extension          = explode(';', $update);
          if (empty($currentVersion)) {
  	        $currentVersion   = (string)$this->config->get($extension[2] . '_version');
  	      }	 
          if (!empty($currentVersion) && version_compare((string)$extension[1], $currentVersion, '>')) {    
            $extension_message  = "<extensions> - " . $extension[0] . " <strong>". $extension[1] . "</strong> (<a class='releasenote' href='". $this->url->link($this->getModulePath() . $extension[3] . '/viewChangelog', $this->getUserToken(), $this->getUrlSSL()) . "&changelog=" . $extension[2] . "&title=". $extension[0] . "'>" . $this->language->get('entry_view_changelog'). "</a> or check <a href='". $this->url->link($this->getModulePath() . $extension[3], $this->getUserToken(), $this->getUrlSSL()) . "'>extension settings</a>)</extensions>";
            $extentions_text[]  = $extension_message;
          }
        }
        if (!empty($extentions_text)) {
          $updates_str = sprintf($this->language->get('help_updates_available'), (count($updates)>1 ? count($updates) : ''), implode('<br />', $extentions_text));
        } else {
          // No updates available 
          $this->OwcLoader->OwcBase->updateLastCheckForUpdates('', $settings_updates, $settings_last_check_updates);       
          $this->config->set($settings_updates, '');
        }
      }
	  }  	  
	  return $updates_str;
	}
	
	/**
	* Get the updates.
	*
	* @param   string settings name for check updates 
	*
	* @return  update array  	
  *	 
	* @since   2.4.2
	*/	
	public function getUpdatesAvailable($settings_updates) {		 
	  $updates = $this->config->get($settings_updates);	 	  
	  return is_array($updates) && !empty($updates) ? $updates : array();
  } 	
	
	/**
	* Get updates.
	*
	* @param   string Extension name 
	*
	* @return  array with update strings 	
  *	 
	* @since   1.0
	*/	
	public function getUpdates($extention_filename, $extention_name="") { 
	  $updates        = array();   	 
	  
	  $this->logDebug("getUpdates for: extention_filename=".$extention_filename.", extention_name=".$extention_name);
	  
	  $updateManifest = $this->OwcLoader->OwcUpdateHelper->getUpdateManifest($extention_filename);
	  if ($updateManifest) {
      $versions = $updateManifest->xpath('//version');       
      foreach ($versions as $version) {        
        $config_name = explode(';', $version['name']);
        $currentVersion = (string)$this->config->get($config_name[0] . '_version');	 
        if (empty($extention_name)) {
          $extention_name = $this->language->get(str_replace($extention_filename, 'entry_ext', (string)$version['name'])) . " " . $this->language->get('text_ext_name');                           
        }        
        if ((!empty($currentVersion) && version_compare((string)$version['version'], $currentVersion, '>')) || isset($this->request->get['owcupdates'])) {    
          //if (class_exists(str_replace('_', '', (string)$version['name']))) {                    
            $updates[]  = $extention_name . ";" . $version['version'] . ";".$version['name'];	                           
          //}
        }              
      }       
    }    
    return $updates;
  } 

  /**
	* Check if an update check must be done.
	*
	* @param   string Extension settings name for last check updates 
  *	 
	* @since   1.0
	*/	
	public function checkForUpdate($ext_check_updates, $ext_last_check_updates) {	
	  $update      = false;
	  if ($this->config->get($ext_check_updates)) {
  	  $update = true;
  	  $last_update = $this->config->get($ext_last_check_updates);  	 
  	  if (isset($last_update) && !empty($last_update)) {
  	    $start_date   = new DateTime($last_update);  	   
        $since_start  = $start_date->diff(new DateTime());       
        if (($since_start->days*24) < self::UPDATE_MESSAGE_TIME) {
          $update = false;
        }    
      } 
    }
    return $update;	  
	}
	
  /**
	* Set the time of the last update check.
  *	 
  * @param   string Extension settings name for updates 
  * @param   string Extension settings name for check updates 
  *		
	* @since   1.0
	*/
	public function updateLastCheckForUpdates($updates, $ext_updates, $ext_check_updates) { 		
		$date = new DateTime('Now');
		
		$this->db->query("UPDATE `" . DB_PREFIX . "setting` SET `value` ='" . $date->format("Y-m-d H:i:s") ."' WHERE `key` = '" . $ext_check_updates. "'");   		
		if ($this->isV22AndLower()) {
		  $this->config->set($ext_updates, serialize($updates));
		  $this->db->query("UPDATE `" . DB_PREFIX . "setting` SET `value` ='" . $this->db->escape(serialize($updates)) ."', serialized = '1' WHERE `key` = '" . $ext_updates . "'");   
		} else {				
		  $this->config->set($ext_updates, json_encode($updates, true));
		  $this->db->query("UPDATE `" . DB_PREFIX . "setting` SET `value` ='" . $this->db->escape(json_encode($updates, true)) ."', serialized = '1' WHERE `key` = '" . $ext_updates . "'");   
		}
	}	
	
	/**
	* Merge update strings
  *	 		
	* @since   2.4.7
	*/
	public function mergeUpdateString($update_str, $update_available_msg) {	  
	  $update_available_msg = $this->OwcLoader->OwcHelper->getElementTag("<extensions>","</extensions>", $update_available_msg);
	  return $this->OwcLoader->OwcHelper->insertAfterElementTag("<extensions>","</extensions>", "<br />" . $update_available_msg, $update_str);
	}
	
	/**
	* Reset the time of the last update check to force the update.
  *	 
  * @param   string Extension settings name for updates 
  * @param   string Extension settings name for check updates 
  *		
	* @since   1.0
	*/
	public function forceUpdateLastCheckForUpdates($ext_updates, $ext_check_updates) { 
	  $this->db->query("UPDATE `" . DB_PREFIX . "setting` SET `value` ='' WHERE `key` = '" . $ext_check_updates. "'");   
		$this->db->query("UPDATE `" . DB_PREFIX . "setting` SET `value` ='' WHERE `key` = '" . $ext_updates . "'");   
	}
	
	/**
	* Get path to admin module.
  *	 
	* @since   1.2
	*/
	public function getModulePath() {
	  if (version_compare(VERSION, '2.2.0.0', '<=')) {  
	    return "module/"; 
	  }

	  return "extension/module/";	
	}
	
	/**
	* Get path to admin extension module.
  *	 
	* @since   1.3
	*/
	public function getExtensionPath() {
	  if (version_compare(VERSION, '2.2.0.0', '<=')) {  
	    return "extension/module"; 
	  }
	  if (version_compare(VERSION, '2.3.0.3', '<=')) {  
	    return "extension/extension"; 
	  }
	  return "marketplace/extension";	
	}
	
	/**
	* Get path to catalog extension total.
  *	 
	* @since   1.6
	*/
	public function getExtensionTotalPath() {
	  if (version_compare(VERSION, '2.2.0.0', '<=')) {  
	    return "total/"; 
	  }
	  return "extension/total/"; 	  
	}
	
	/**
	* Get path to admin customer.
  *	 
	* @since   1.2
	*/
	public function getCustomerPath($underscore=false) {
	  $path = '';
	  if (version_compare(VERSION, '2.1.0.1', '<')) {  	    
	    $path = "sale/customer"; 
	  } else {
	    $path = "customer/customer";	
	  }
	  if($underscore) {
	    $path = str_replace('/', '_', $path);  
	  } 
	  return $path;  
	}
	
	/**
	* get event model
  *	 
	* @since   2.3
	*/
	public function getEventModel() {
    if ($this->isV3()) {
        $this->load->model('setting/event');
        return $this->model_setting_event;
    } else {
        $this->load->model('extension/event');
        return $this->model_extension_event;
    }
  }
	
	/**
	* SSL attribute for url->link function
  *	 
	* @since   1.4
	*/
	public function getUrlSSL() {
		if (version_compare(VERSION, '2.3.0.3', '<=')) {  
      return 'SSL';
		} else {
	    return true;
	  }
	}
		
	/**
	* Get template filename.
  *	 
	* @since   1.5
	*/	
	public function getTemplate($string) {
	  if (version_compare(VERSION, '2.2.0.0', '<=')) {  
	    return $string; 
	  }
	  if (version_compare(VERSION, '2.3.0.3', '<=')) {  
	    return $string; 
	  }	  
	  //$this->config->set('template_engine', 'template'); 
	  return str_replace('.tpl', '', $string);	
	}	

	
	/**
	* Load template .tpl. Also load the old template within OpenCart 3. 
  *	 
	* @since   1.5
	*/	
	public function loadView($template, $data) {	  
	  
	  $path = $this->getModulePath();
	  if (strpos($template, '/') !== false) {
	    $path = "";
	  } 
	  
	  if ($this->OwcLoader->OwcHelper->isAdminUrl()) {	
	    if (version_compare(VERSION, '2.2.0.0', '<=')) {     
	      $output = $this->load->view($path . $this->getTemplate($template), $data);	
	      return $output; 
	    } else {
	      $engine = $this->config->get('template_engine');  	 
    	  if (strpos($template, '.tpl') !== false) {    	     
    			$this->config->set('template_engine', 'template');  			
    		}	
    	  
    	  $output = $this->load->view($path . $this->getTemplate($template), $data);  
    	  $this->config->set('template_engine', $engine);
    	  
    	  return $output; 
	    }
	  } else {
  	  if (version_compare(VERSION, '2.2.0.0', '<=')) {    		
    		if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/' . $path . $template)) {
    			return $this->load->view($this->config->get('config_template') . '/template/' . $path . $this->getTemplate($template), $data);
    		} else {    		  
    			return $this->load->view('default/template/' . $path . $this->getTemplate($template), $data);
    		}
    	} else {   		
    	  $engine     = $this->config->get('template_engine'); 
    	  $directory  = $this->config->get('template_directory');  	 
    	  if (strpos($template, '.tpl') !== false) {    	     
    			$this->config->set('template_engine', 'template');  			
    		}		 		    		
    		
    	  $this->config->set('template_directory', 'default/template/');
    	  $output = $this->load->view($path . $this->getTemplate($template), $data);  
    	  $this->config->set('template_engine', $engine);
    	  $this->config->set('template_directory', $directory);   	   	    	  
    	  
    	  return $output; 	  
  	  }  	
  	}
    return "";  
	}
	
	/**
	* Get user token of user token string
  *	 
	* @since   1.4
	*/
	public function getUserToken($string=true) {
	  if (version_compare(VERSION, '2.3.0.3', '<=')) {  
	    if (isset($this->session->data['token'])) {
	      return $string ? 'token=' . $this->session->data['token'] : $this->session->data['token']; 
	    }
	  }
	  if (isset($this->session->data['user_token'])) {
	    return $string ? 'user_token=' . $this->session->data['user_token'] : $this->session->data['user_token'];	
	  }
	  return '';
	}
	
	/**
	* Get user token name
  *	 
	* @since   1.4
	*/
	public function getUserTokenName() {
	  if (version_compare(VERSION, '2.3.0.3', '<=')) {  
	    return 'token'; 
	  }
	  return 'user_token';	
	}
	
	/**
	* addModule
  *	 
	* @since   1.4
	*/
	public function addModule($code, $data) {
	  if (version_compare(VERSION, '2.3.0.3', '<=')) {  
	    $this->load->model('extension/module');				  
	    $this->model_extension_module->addModule($code, $data);
	  } else {
	    $this->load->model('setting/module');
			$this->model_setting_module->addModule($code, $data);
	  }
	}
	
	/**
	* editModule
  *	 
	* @since   1.4
	*/
	public function editModule($module_id, $data) {
		if (version_compare(VERSION, '2.3.0.3', '<=')) {  
		  $this->load->model('extension/module');		
		  $this->model_extension_module->editModule($module_id, $data);
		} else {
	    $this->load->model('setting/module');
			$this->model_setting_module->editModule($module_id, $data);
	  }
	}
	
	/**
	* getModule
  *	 
	* @since   1.4
	*/	
	public function getModule($module_id) {
		if (version_compare(VERSION, '2.3.0.3', '<=')) {  
		  $this->load->model('extension/module');		
		  return $this->model_extension_module->getModule($module_id);
		} else {
	    $this->load->model('setting/module');
			return $this->model_setting_module->getModule($module_id);
	  }
	}
	
	/**
	* Convert to array for storing in database field
  *	 
  * @param   array
  * @param   element
  *		
	* @since   2.4.9
	*/
	public function convertToConfigArray($data, $element) { 		
		
		if (isset($data[$element]) && !empty($data[$element])) {
      if ($this->isV22AndLower()) {
        return serialize($data[$element]);   
  		} else {						  
  		  return json_encode($data[$element], true);   
  		}  		
    } 	
    return '';	
	}	
	
	/**
	* Convert from array for storing in database field
  *	 
  * @param   array
  * @param   element
  *		
	* @since   2.4.9
	*/
	public function convertFromConfigArray($data, $element) { 		
		
		if (isset($data[$element]) && !empty($data[$element])) {
      if ($this->isV22AndLower()) {
        return unserialize($data[$element]);   
  		} else {						  
  		  return json_decode($data[$element], true);   
  		}  		
    } 	
    return '';	
	}	
	
	/**
	 * Get consumer address by Open Cart address_id.
	 *
	 * @param	int OpenCart Consumer Address ID.
	 * 
	 */		 	
  public function getAddress($address_id) {
		$address_query = $this->db->query("SELECT DISTINCT * FROM " . DB_PREFIX . "address WHERE address_id = '" . (int)$address_id . "'");

		if ($address_query->num_rows) {
			$country_query = $this->db->query("SELECT * FROM `" . DB_PREFIX . "country` WHERE country_id = '" . (int)$address_query->row['country_id'] . "'");

			if ($country_query->num_rows) {
				$country = $country_query->row['name'];
				$iso_code_2 = $country_query->row['iso_code_2'];
				$iso_code_3 = $country_query->row['iso_code_3'];
				$address_format = $country_query->row['address_format'];
			} else {
				$country = '';
				$iso_code_2 = '';
				$iso_code_3 = '';
				$address_format = '';
			}

			$zone_query = $this->db->query("SELECT * FROM `" . DB_PREFIX . "zone` WHERE zone_id = '" . (int)$address_query->row['zone_id'] . "'");

			if ($zone_query->num_rows) {
				$zone = $zone_query->row['name'];
				$zone_code = $zone_query->row['code'];
			} else {
				$zone = '';
				$zone_code = '';
			}

			$address_data = array(
				'address_id'     => $address_query->row['address_id'],
				'firstname'      => $address_query->row['firstname'],
				'lastname'       => $address_query->row['lastname'],
				'company'        => $address_query->row['company'],
				'address_1'      => $address_query->row['address_1'],
				'address_2'      => $address_query->row['address_2'],
				'postcode'       => $address_query->row['postcode'],
				'city'           => $address_query->row['city'],
				'zone_id'        => $address_query->row['zone_id'],
				'zone'           => $zone,
				'zone_code'      => $zone_code,
				'country_id'     => $address_query->row['country_id'],
				'country'        => $country,
				'iso_code_2'     => $iso_code_2,
				'iso_code_3'     => $iso_code_3,
				'address_format' => $address_format,
				'custom_field'   => json_decode($address_query->row['custom_field'], true)
			);

			return $address_data;
		} else {
			return false;
		}
	}
	
	/**
	* Get url_alias / seo_url table
  *	 
	* @since   1.7
	*/
	public function getUrlAliasTableName($string=true) {
	  if (version_compare(VERSION, '2.3.0.3', '<=')) {  
	    return 'url_alias'; 
	  }
	  return 'seo_url';	
	}
	
	/**
	* add Ckeditor support
  *	 
	* @since   1.9
	*/	
	public function addWYSIWYGEditorSupport(&$data, $summernote=false) {
	  /* CKE editor */   
		$data['ckeditorplus_language'] = 'en';
		$data['ckeditorplus_skin'] = 'moono';
		$data['ckeditorplus_status'] = 0;		
		
		if ($this->config->get('ckeditorplus_status')) {			
				$data['ckeditorplus_status'] = $this->config->get('ckeditorplus_status');
				if ($this->config->get('ckeditorplus_language')) {$data['ckeditorplus_language'] = $this->config->get('ckeditorplus_language');}
				if ($this->config->get('ckeditorplus_skin')) {$data['ckeditorplus_skin'] = $this->config->get('ckeditorplus_skin');}				
		} else
		if (file_exists(DIR_APPLICATION . '/view/javascript/ckeditor/ckeditor.js')) {
			$data['ckeditorplus_status'] = 1;
			$this->document->addScript('view/javascript/ckeditor/ckeditor.js');
		}
		else {      
			if (version_compare(VERSION, '2.2.0.0', '>') || $summernote) {  
				$this->document->addScript('view/javascript/summernote/summernote.js');
				$this->document->addStyle('view/javascript/summernote/summernote.css');
				$this->document->addScript('view/javascript/summernote/opencart.js');
			}
		}	  
	}
	
	/**
	* Clear Nitro product cache
  *	 
	* @since   2.0
	*/
	public function clearNitroProductCache($product_id) {		   
	  if (is_dir(DIR_SYSTEM . '/nitro')) { 
      $this->load->model('tool/nitro');    
      if (getNitroPersistence('PageCache.ClearCacheOnProductEdit')) {       
        if ($product_id > 0) { 
          $this->model_tool_nitro->clearProductCache((int)$product_id);          
          $this->load->model('catalog/product');
          $current_product_categories = $this->model_catalog_product->getProductCategories($product_id);
          foreach ($current_product_categories as $nitro_category_id) {                                 
            $this->model_tool_nitro->clearCategoryCache((int)$nitro_category_id);             
          }      
        } else {
          truncateNitroProductCache();
          $filename = getQuickCacheRefreshFilename();
          touch($filename);
        }        
      }
    }
  }
  
  public function fix_reg($str) {
		$str = str_replace('?', '\?', $str);
		$str = str_replace('{', '\{', $str);
		$str = str_replace('}', '\}', $str);
		return $str;
	}
  
  /**
	 * Check if PHP code exists in string .
	 *
	 * @param	text The string to check for PHP code  
	 * 
	 */		 
	public function checkPHPcode($text) {	 
	  $regexp     = '/(.*?)'.$this->fix_reg("<?php").'\s+(.*?)'.$this->fix_reg("?>").'(.*)/s';	  
		return preg_match($regexp, $text, $matches);		
	}
  
  /**
	* is version 2.0
  *	 
	* @since   2.5.3
	*/
  public function isV20AndLower() {
      return version_compare(VERSION, '2.2.0.0', '<');
  }
  
  /**
	* is version 2.0
  *	 
	* @since   2.4
	*/
  public function isV20() {
      return version_compare(VERSION, '2.2.0.0', '<');
  }
  
  /**
	* is version 2.1
  *	 
	* @since   2.4
	*/
  public function isV21() {
      return version_compare(VERSION, '2.1.0.1', '>=') && version_compare(VERSION, '2.1.0.2', '<=');
  }
  
  /**
	* is version 2.1
  *	 
	* @since   2.5.3
	*/
  public function isV21AndHiger() {
      return version_compare(VERSION, '2.1.0.1', '>=');
  }

  /**
	* is version 2.2
  *	 
	* @since   2.5.3
	*/
  public function isV22AndLower() {
      return version_compare(VERSION, '2.3', '<');
  }
  
  /**
	* is version 2.2
  *	 
	* @since   2.4
	*/
  public function isV22() {
      return version_compare(VERSION, '2.2.0.0', '>=') && version_compare(VERSION, '2.3', '<');
  }

  /**
	* is version 2.3
  *	 
	* @since   2.4
	*/
  public function isV23() {
      return version_compare(VERSION, '3.0', '<') &&
             version_compare(VERSION, '2.3', '>=');
  }
  
  /**
	* is version 2.0
  *	 
	* @since   3.0
	*/
  public function isV3() {
      return version_compare(VERSION, '3.0', '>=');
  }
  
  /**
	* is Journal 2 theme active
  *	 
	* @since   2.1
	*/
  public function isJournal2() {
    if (strpos($this->config->get('theme_default_directory'), 'journal2') === 0) {
      return true;
    }
    if (strpos($this->config->get('config_theme'), 'journal2') === 0) {
      return true;
    }
    if (strpos($this->config->get('config_template'), 'journal2') === 0) {
      return true;
    }
    return false;
  }    
    	
  /**
	* is Journal 3 theme active
  *	 
	* @since   2.1
	*/
  public function isJournal3() {
    if (strpos($this->config->get('theme_default_directory'), 'journal3') === 0) {
      return true;
    }
    if (strpos($this->config->get('config_theme'), 'journal3') === 0) {
      return true;
    }
    if (strpos($this->config->get('config_theme'), 'theme_journal3') === 0) {
      return true;  
    }
    if (strpos($this->config->get('config_template'), 'journal3') === 0) {
      return true;
    }   
    return false;
  }  
  
  /**
	* is Ajax Quick Checkout active
  *	 
	* @since   2.2
	*/
  public function isAjaxQuickCheckout() {
    if ($this->config->get('d_quickcheckout_status')) {        
      return true;
    }
    return false; 
  }
  
  /**
	* is Quick Checkout by MarketInSG active
  *	 
	* @since   2.2
	*/
  public function isQuickCheckout() {
    if ($this->config->get('quickcheckout_status')) {         
      return true;
    }
    return false; 
  } 
  
  /**
	* is OnePage Checkout by Extension Bazaar active
  *	 
	* @since   2.2
	*/
  public function isOnePageCheckout() {
    if ($this->config->get('onepagecheckout_status')) {        
      return true;
    }
    return false; 
  }  
  
  /**
	* is Ajax Best Checkout by xtensions active
	* https://www.opencart.com/index.php?route=marketplace/extension/info&extension_id=20736
  *	 
	* @since   2.4.5
	*/
  public function isAjaxBestCheckout() {
    if ($this->registry->has('xtensions_checkout') && $this->xtensions_checkout->isActive('xtensions_best_checkout',$this->config->get('config_store_id'))){        
      return true;
    }
    return false; 
  }  
  
  /**
	* is Quick N Easy Checkout by DevmanExtensions active
  *	 
	* @since   2.4.5
	*/
  public function isQuickNEasyCheckout() {
    if ($this->config->get('poc_status')) {       
      return true;
    }
    return false; 
  }  
  
  /**
	* is Quick Checkou by Modulepoints active
  *	 
	* @since   2.5.1
	*/
  public function isQuickCheckoutByModulePoints() {
    if ($this->config->get('mpcheckout_status')) {            
      return true;
    }
    return false; 
  }    
  
  /**
	* Load language file and reload heading_title
  *	 
	* @since   2.4.1
	*/
  public function language($language) {
    $heading = $this->language->get('heading_title');      
    $data = $this->load->language($this->getModulePath() . $language);	
    $data['heading_title'] = $heading;
    $this->language->set('heading_title', $heading);    
    return $data;
  }
  
  /**
	* Check mod files if both vqmod and ocmod is installed.
  *	 
	* @since   2.4.3
	*/
  public function checkModFiles($modfile, $type='ocmod') {	
    
    $mod_type = $type;	

		if (is_file(DIR_SYSTEM.'../vqmod/xml/' . $modfile . '.xml') && is_file(DIR_SYSTEM.'../system/' . $modfile . '.ocmod.xml')) {			
			
			if ($type == 'vqmod') {
			  $this->rename_files(DIR_SYSTEM.'../system/owc_core.xml', '.xml', '.xml_');	
		  	$this->rename_files(DIR_SYSTEM.'../system/'.str_replace("owc_", "owc_core_", $modfile).'*.xml', '.xml', '.xml_');	
				$this->rename_files(DIR_SYSTEM.'../system/'.$modfile.'*.xml', '.xml', '.xml_');									
			} else { 		
			  $this->rename_files(DIR_SYSTEM.'../vqmod/xml/owc_core.xml', '.xml', '.xml_');	
		  	$this->rename_files(DIR_SYSTEM.'../vqmod/xml/'.str_replace("owc_", "owc_core_", $modfile).'*.xml', '.xml', '.xml_');						  
				$this->rename_files(DIR_SYSTEM.'../vqmod/xml/'.$modfile.'*.xml', '.xml', '.xml_');			
				
				// Delete mods.cache
		    if (is_file(DIR_SYSTEM.'../vqmod/mods.cache')) {
			    unlink(DIR_SYSTEM.'../vqmod/mods.cache');
		    }								
			}
			
			if (version_compare(VERSION, '3', '>=')) {
			  $modifications_url = $this->url->link('marketplace/modification', $this->getUserToken(), 'SSL');
		  } else {
			  $modifications_url = $this->url->link('extension/modification', $this->getUserToken(), 'SSL');
		  }			
			
			return "Warning: Both VQMOD and OCMOD versions are uploaded. OCMOD is recommended for opencart versions 2.x and later so VQMOD is disabled by renaming the xml files!<br /><a href='".$modifications_url."'>Click here</a> to go to the modification page to refresh modifications. In case of an error please delete the files/folders inside 'storage/modification' folder. And refresh again.";
			
		} else 
		if (is_file(DIR_SYSTEM.'../vqmod/xml/' . $modfile . '.xml')) { 
		  $mod_type = 'vqmod';		  
		} else 
		if (is_file(DIR_SYSTEM.'../system/' . $modfile . '.ocmod.xml')) { 
		  $mod_type = 'ocmod';
		}		
		
		if ((VERSION == '2.0.0.0')){
			$code_column = 'group';
		}else {
			$code_column = 'code';
		}		
		
		$mod_file = $this->config->get($this->db->escape($modfile) . "_mod_file");
		if (empty($mod_file)) {
		  $this->db->query("INSERT INTO " . DB_PREFIX . "setting SET store_id = '0', `".$code_column."` = '" . $this->db->escape($modfile) . "_installer', `key` = '" . $this->db->escape($modfile . '_mod_file') . "', `value` = '".$mod_type."'");  
		} else {
		  $this->db->query("UPDATE " . DB_PREFIX . "setting SET store_id = '0', `".$code_column."` = '" . $this->db->escape($modfile) . "_installer', `key` = '" . $this->db->escape($modfile . '_mod_file') . "', `value` = '".$mod_type."' WHERE `key` = '" . $this->db->escape($modfile . '_mod_file') . "'");
		}		
		$this->config->set($this->db->escape($modfile) . "_mod_file", $mod_type);
		return "";
	}	
	
	
	/**
	* Check mod files if both vqmod and ocmod is installed.
  *	 
	* @since   2.4.3
	*/
	public function rename_files($pattern, $search, $replace) {
  	$pathnames = glob($pattern);
  
  	foreach ($pathnames as $pathname) {
  		// check if the pathname is a file
  		if (!is_file($pathname)) {
  			continue;
  		}
  		
  		// get the dir and filename
  		$dirname = dirname($pathname);
  		$filename = basename($pathname);
  
  		// replace $search by $replace in the filename
  		$new_pathname = $dirname . '/' . str_replace($search, $replace, $filename);
      
  		// check if the new file exists
  		if (file_exists($new_pathname)) {
  			//throw new Exception('The file ' . $new_pathname . ' already exists');
  			$this->logDebug('The file ' . $new_pathname . ' already exists');
  			continue;
  		}
  		
  		$this->logDebug($pathname . " -> " . $new_pathname);
  
  		// rename the file  		
  		rename($pathname, $new_pathname);
  	}
  }
  
  public function getFrontLinkFromUrl($url) {	 
    if ($this->OwcLoader->OwcHelper->isInternal($url)) {
		  if (strpos($url, 'product/product&') !== false) {
		    $link	= explode('&', html_entity_decode($url, ENT_QUOTES, 'UTF-8'));
		    $url = $this->getFrontLink('product/product', $link[1]);
		  } else
		  if (strpos($url, 'product/category&') !== false) {
		    $link	= explode('&', html_entity_decode($url, ENT_QUOTES, 'UTF-8'));
		    $url = $this->getFrontLink('product/category', $link[1]);
		  } else
		  if (strpos($url, 'information/information&') !== false) {
		    $link	= explode('&', html_entity_decode($url, ENT_QUOTES, 'UTF-8'));
		    $url = $this->getFrontLink('information/information', $link[1]);
		  } else
		  if (strpos($url, 'product/search&') !== false) {
		    $link	= explode('&', html_entity_decode($url, ENT_QUOTES, 'UTF-8'));
		    $url = $this->getFrontLink('product/search', $link[1]);
		  } else {
		    $url = $this->getFrontLink($url);
		  }
		}  	
		
		return $url;
	}  
  
  function getFrontLink($route, $args = '', $secure = false) {
    $url      = new Url(HTTP_CATALOG, $this->config->get('config_secure') ? HTTP_CATALOG : HTTPS_CATALOG);
    $catalog  = defined('DIR_CATALOG') ? DIR_CATALOG : DIR_APPLICATION; 
    
	  if ($this->config->get('config_seo_url')) {     
      
      if (version_compare(VERSION, '2.2.0.0', '<')) {
        if (class_exists('VQMod')) {
          require_once(VQMod::modCheck(VQMod::modCheck(modification($catalog . 'controller/common/seo_url.php'))));
        } else {
          require_once(modification($catalog . 'controller/common/seo_url.php'));
        }  
        $rewriter = new ControllerCommonSeoUrl($this->registry);
      } else {
        if (class_exists('VQMod')) {
          require_once(VQMod::modCheck(VQMod::modCheck(modification($catalog . 'controller/startup/seo_url.php'))));
        } else {
          require_once(modification($catalog . 'controller/startup/seo_url.php'));
        }          
        $rewriter = new ControllerStartupSeoUrl($this->registry);
      }
      $url->addRewrite($rewriter);
    }
    return $url->link($route, $args, $secure);
  }
  
  function isFileAndNotOlderThan($file, $time=60*60*12) {    
    return is_file($file) && (time() - filemtime($file) < $time);
  }	
	
	/**
	* Set logfile
  *	 
	* @since   1.0
	*/
	public function setLogfile($logfile) {
	  $this->logfile = $logfile;  
	}
	
	/**
	* Set log debug
  *	 
	* @since   1.0
	*/
	public function setLogDebug($debug) {
	  $this->debug = $debug;  
	}
	
	/**
	* Set log debug
  *	 
	* @since   1.0
	*/
	public function isLogDebug() {
	  return $this->debug;  
	}
	
	/**
	* Log info message
  *	 
	* @since   1.0
	*/
	public function logInfo($text) {
	  
	  if ($this->debug) {
	    if (!isset($this->logger)) {
	      $this->logger = new Log($this->logfile);   
	    }
	    $this->logger->write("INFO:  " . (is_array($text) ? print_r($text, true) : $text));	
	  }	
	  return $text;
	}
	
	/**
	* Log debug message
  *	 
	* @since   1.0
	*/
	public function logDebug($text) {	 
	  if ($this->debug) {
	    if (!isset($this->logger)) {
	      $this->logger = new Log($this->logfile);   
	    }
	    $this->logger->write("DEBUG: " . (is_array($text) ? print_r($text, true) : $text));	
	  }	
	  return $text;
	}
	
	/**
	* Log error message
  *	 
	* @since   1.0
	*/
	public function logError($text) {	  
	  if (!isset($this->logger)) {
	    $this->logger = new Log($this->logfile);   
	  }
	  $this->logger->write("ERROR: " . (is_array($text) ? print_r($text, true) : $text));		
	  return $text;
	}	 	
	
	public function startPerformanceLog($filename=null) {
	  if (isset($filename)) {
	    $this->logfile_performance = $filename;  	   
      $this->performance = new Log($this->getPerformanceFilename()); 
    }	  
    
	  if (!isset($this->startTime1_performance)) {
	    $this->startTime1_performance = microtime(TRUE); 	 	   
	    $this->performance->write("-----------------------PERFORMANCE CHECK START ".$this->startTime1_performance."--------");	
	  }
	  $GLOBALS['startTime1_performance'] = $this->startTime1_performance;
	}	

	public function endPerformanceLog() {	 	   
	  if (isset($this->startTime1_performance)) {	    
	    $end_time = microtime(TRUE);   
	    $time_taken = $end_time - $this->startTime1_performance;    
	    $time_taken = round($time_taken,5);          
      $time_taken_str = "page loaded in ".$time_taken .' seconds';     
	    $this->performance->write("-----------------------PERFORMANCE CHECK END ".$this->startTime1_performance."--------");	
	    $this->performance->write($time_taken_str);   
    	$this->performance->write("---------------------------------------------------------------------");  
	  }
	}	
	
	public function getPerformanceStartTime() {	
	  if (isset($GLOBALS['startTime1_performance'])) {	    
	    return $GLOBALS['startTime1_performance'];  
	  }   
	  return microtime(TRUE);
	} 	   

	/**
	* Log performance message
  *	 
	* @since   1.0
	*/
	public function logPerformance($text, $startTime2=null) {  
	  
    //if (!isset($this->performance)) {
      $this->performance = new Log($this->getPerformanceFilename());  
    //}     	     
    
    $startTime1 = $this->startTime1_performance;
    $time_taken_str = "";
    $time_taken = 0;
    if ($startTime2 != null) {         
      $end_time = microtime(TRUE);              
      $time_taken = $end_time - $startTime2;     
      $time_taken = round($time_taken,5);    
      $time_taken_str = " (loaded in ".$time_taken .' seconds)';
    }              

    if ($time_taken > 1 && $startTime2 != null) {  
      $this->performance->write("-----PERFORMANCE CHECK----- " . $time_taken . " ---------------------");	
    	$this->performance->write((is_array($text) ? print_r($text, true) : $text) . $time_taken_str);   
    	$this->performance->write("---------------------------------------------------------------------"); 
    } else {
      $this->performance->write((is_array($text) ? print_r($text, true) : $text) . $time_taken_str);	
    }	  	
	}	
	
	public function getPerformanceFilename() {
	    return substr(str_replace("%1", str_replace("/", '-', str_replace("?", '-', strtok($_SERVER["REQUEST_URI"],'&'))), $this->logfile_performance), 0, 100);
	}	
}

?>
